@@ -1,13 +1,21 @@
 import inspect
 import warnings
 
-from typing import Any, Dict, List, Optional, Tuple, Union
+from enum import Enum, auto
+from typing import Any, Dict, List, Optional, Tuple, Type, Union
 
 from .generator import Generator
 from .providers import BaseProvider
 from .proxy import Faker
 
 
+class FakerEnum(Enum):
+    """Required for faker.providers.enum"""
+
+    A = auto
+    B = auto
+
+
 class Documentor:
     def __init__(self, generator: Union[Generator, Faker]) -> None:
         """
@@ -52,7 +60,7 @@ class Documentor:
                 continue
 
             arguments = []
-            faker_args: List[str] = []
+            faker_args: List[Union[str, Type[Enum]]] = []
             faker_kwargs = {}
 
             if name == "binary":
@@ -65,6 +73,9 @@ class Documentor:
                     }
                 )
 
+            if name == "enum":
+                faker_args = [FakerEnum]
+
             if with_args:
                 # retrieve all parameter
                 argspec = inspect.getfullargspec(method)
