@@ -5,8 +5,5 @@ class Provider(CurrencyProvider):
 
     price_formats = ["#,##", "%#,##", "%##,##", "%.###,##", "%#.###,##"]
 
-    def pricetag(self):
-        return (
-            self.numerify(self.random_element(self.price_formats))
-            + "\N{no-break space}zł"
-        )
+    def pricetag(self) -> str:
+        return self.numerify(self.random_element(self.price_formats)) + "\N{no-break space}zł"
