@@ -1983,7 +1983,7 @@ class Provider(BaseProvider):
             time_params = cls._parse_date_string(value)
             return datetime_to_timestamp(now + timedelta(**time_params))  # type: ignore
         if isinstance(value, int):
-            return datetime_to_timestamp(now + timedelta(value))
+            return value
         raise ParseError(f"Invalid format for date {value!r}")
 
     @classmethod
@@ -2411,11 +2411,11 @@ class Provider(BaseProvider):
     def year(self) -> str:
         return self.date("%Y")
 
-    def century(self, min_length: Optional[int] = None, max_length: Optional[int] = None) -> str:
+    def century(self) -> str:
         """
         :example: 'XVII'
         """
-        return self.random_element(self.centuries, min_length, max_length)
+        return self.random_element(self.centuries)
 
     def timezone(self) -> str:
         return self.generator.random.choice(self.random_element(self.countries)["timezones"])  # type: ignore
